@@ -2,7 +2,6 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Union
 
-from sc2 import unit as unit_module
 from sc2.constants import COMBINEABLE_ABILITIES
 from sc2.ids.ability_id import AbilityId
 from sc2.position import Point2
@@ -12,6 +11,7 @@ if TYPE_CHECKING:
 
 
 class UnitCommand:
+
     def __init__(self, ability: AbilityId, unit: Unit, target: Union[Unit, Point2] = None, queue: bool = False):
         """
         :param ability:
@@ -20,9 +20,13 @@ class UnitCommand:
         :param queue:
         """
         assert ability in AbilityId, f"ability {ability} is not in AbilityId"
-        assert isinstance(unit, unit_module.Unit), f"unit {unit} is of type {type(unit)}"
-        assert target is None or isinstance(
-            target, (Point2, unit_module.Unit)
+        assert unit.__class__.__name__ == "Unit", f"unit {unit} is of type {type(unit)}"
+        assert any(
+            [
+                target is None,
+                isinstance(target, Point2),
+                unit.__class__.__name__ == "Unit",
+            ]
         ), f"target {target} is of type {type(target)}"
         assert isinstance(queue, bool), f"queue flag {queue} is of type {type(queue)}"
         self.ability = ability
